###################################################
### chunk number 1: vector
###################################################
genus <- c("Daphnia", "Boletus", "Hippopotamus", "Salmo", "Linaria", "Ixodes", "Apis")
species <- c("magna", "edulis", "amphibius", "trutta", "alpina", "ricinus", "mellifera")
weight <- c(0.001, 100, 3200000, 1000, 2.56, 0.001, 0.01)
legs <- as.integer(c(0,0,4,0,0,8,6))
animal <- c(TRUE, FALSE, TRUE, TRUE, FALSE, TRUE, TRUE)


###################################################
### chunk number 2: factor
###################################################
kingdom <- factor(c("animal", "fungi", "animal", "animal", "plant", "animal", "animal"))


###################################################
### chunk number 3: data.frame
###################################################
bio <- data.frame(name=I(paste(genus,species)), weight_g=weight, leg_no=legs, animal=animal, kingdom=kingdom)
# I() prevents that species (a vector of class character) is converted to a factor


###################################################
### chunk number 4: data.frame::write.table eval=FALSE
###################################################
## write.table(bio, file="~/temp/bio.txt", row.names=FALSE, sep="\t")


###################################################
### chunk number 5: data.frame::read.table eval=FALSE
###################################################
## bio.new <- read.table(file="~/temp/bio.txt", header=TRUE, sep="\t", row.names="name", colClasses=c("character", "numeric", "integer", "logical", "factor"))


###################################################
### chunk number 6: matrix
###################################################
mat <- matrix(1:12, nrow=3, ncol=4, byrow=TRUE)
mat1 <- matrix(c(1,5,9,2,6,10,3,7,11,4,8,12), nrow=3, ncol=4)
mat2 <- rbind(c(1:4), c(5:8), c(9:12))
mat3 <- cbind(c(1,5,9), c(2,6,10), c(3,7,11), c(4,8,12))


###################################################
### chunk number 7: matrix::dim.names
###################################################
dimnames(mat) <- list(c("first row", "second row", "last row"), paste("c_",1:4,sep=""))


###################################################
### chunk number 8: list
###################################################
organisms <- list(animals=list(genera=c("Daphnia", "Hippopotamus", "Salmo", "Ixodes", "Apis"), publications=110), plants=list(genera="Linaria", publications=50), fungi="Boletus")


###################################################
### chunk number 10: functions
###################################################
my.t <- function(mean1, mean2, s1, s2, n1, n2, mu.diff=0){
s.pooled <- ((n1-1)*s1^2 + (n2-1)*s2^2)/(n1+n2-2)
t <- ((mean1-mean2)-(mu.diff))/(sqrt(s.pooled*(1/n1 + 1/n2)))
cat(round(t, 2))
cat(paste(": compare to a t dist. with", n1+n2-2, "df \n"))
}


###################################################
### chunk number 11: introduction::ex2 eval=FALSE
###################################################
##     rep(1:3, each=2)
##     rep(1:2, times=3)
## rep(1:3, each=2, times=3)


###################################################
### chunk number 12: introduction::ex3 eval=FALSE
###################################################
##     paste("trt:",rep(1:3, each=2), sep="")
##     paste("ind:", rep(c(1,2), times=3), sep="")


###################################################
### chunk number 13: introduction::ex4 eval=FALSE
###################################################
## experiment <- data.frame(treatment=paste("trt:",rep(1:3, each=2), sep=""), individual= paste("ind:", rep(c(1,2), times=3), sep=""))
## # dimension
## dim(experiment)
## # class
## str(experiment)
## # add column
## experiment <- cbind(experiment, 2:7)
## # save .Rdata
## save(experiment, file="~/Desktop/experiment.Rdata")
## rm(experiment)
## load(file="~/Desktop/experiment.Rdata")
## # write read .txt
## write.table(experiment, file="~/Desktop/experiment.txt")
## rm(experiment)
## experiment <- read.table(file="~/Desktop/experiment.txt", header=TRUE)


###################################################
### chunk number 14: indexing
###################################################
x <- c(11, 44, 33, NA, 22)


###################################################
### chunk number 16: indexing::ex1 eval=FALSE
###################################################
## mat <- matrix(1:16, nrow=4)
## # third column
## mat[,3]
## # diagonal elements
## diagonal <- diag(mat)
## # or by hand
## dia <- cbind(c(1:4),c(1:4))
## diagonal <- mat[dia]
## # antidiagonal elements
## antidia <- cbind(c(1:4), c(4:1))
## antidiagonal <- mat[antidia]


###################################################
### chunk number 17: indexing::ex2 eval=FALSE
###################################################
## vec <- 1:1000
## vec[seq(from=2, to=1000, by=2)] <- 1/(vec[seq(from=2, to=1000, by=2)])


###################################################
### chunk number 18: indexing::ex 3 eval=FALSE
###################################################
## # read doc
## ?swiss
## # sort agriculture
## swiss[order(swiss$Agriculture),]
## # add religion
## swiss <- cbind(swiss, religion=factor("protestant", levels=c("catholic", "protestant")))
## swiss$religion[swiss$Catholic>=50] <- "catholic"
## # sort religion and agriculture
## swiss[order(swiss$religion, swiss$Agriculture),]
## # sort provinces
## swiss[order(row.names(swiss)),]
## # random order
## swiss[sample(row.names(swiss)),]
## # remove education
## swiss$Education <- NULL


###################################################
### chunk number 19: highlevel
###################################################
y <- rnorm(100)
qqnorm(y)
qqnorm(y, xlab="theoretical quantiles", ylab="sample quantiles", main="normal quantile--quantile plot", sub="(because I like it lower case)",  xlim=c(-3,3), ylim=c(-3,3))


###################################################
### chunk number 20: lowlevel
###################################################
qqline(y)


###################################################
### chunk number 21: highlevel
###################################################
par(fg="blue")
y <- rnorm(100)
qqnorm(y, col="red")
qqline(y, col="green")


###################################################
### chunk number 22: highlevel
###################################################
par(col="blue")
y <- rnorm(100)
qqnorm(y, col=rgb(1,0,0))
qqline(y, col="#00FF00")


###################################################
### chunk number 23: graphics::ex1 eval=FALSE
###################################################
## data(trees)
## # a)
## pairs(trees)
## xxp(trees)
## # b)
## pdf(file="~/Desktop/trees_example.pdf", width=13/2.540, height=9/2.540)
## plot(trees$Volume ~ trees$Girth)
## dev.off()
## # c)


###################################################
### chunk number 24: graphics::ex2 eval=FALSE
###################################################
## hist(swiss$Fertility)
## plot(swiss$religion, swiss$Fertility)


###################################################
### chunk number 25: graphics::ex3 eval=FALSE
###################################################
## pdf("~/Desktop/swissdata.pdf", width=13/2.540, height=9/2.540)
## par(mar=c(4,4,4,4))
## plot(Agriculture~Fertility, data=swiss, main="swiss data (1888)", xlab="fertility", xlim=c(1,100), ylim=c(1,100), axes=FALSE, ylab="", col="red")
## points(Examination~Fertility, data=swiss, pch=3, xlim=c(1,100), col="blue")
## axis(side=1)
## axis(side=2, col.axis="red", col="red")
## mtext(text="agriculture", side=2, line=3,col="red")
## axis(side=4, col.axis="blue", col="blue")
## mtext(text="examination", side=4, line=3,col="blue")
## legend(x=10, y=90, legend=c("agriculture", "examination"), col=c("red", "blue"), text.col=c("red", "blue"), pch=c(1,3))
## dev.off()


###################################################
### chunk number 27:  eval=FALSE
###################################################
## probability <- seq(from=0.0001, to=0.9999, length.out=1000)
## quantile <- qchisq(probability, df=3)
## density <- dchisq(quantile, df=3)
## # ploting the density
## plot(density ~ quantile, type="n")
## lines(density ~ quantile)
## abline(v=3, lty=2)
## # the probability that a value is smaler (larger) than 7
## pchisq(7, df=3)
## pchisq(7, df=3, lower.tail=FALSE)
## 
## 
## # the density at quantile=7
## dchisq(7, df=3)


###################################################
### chunk number 28: grphical::ex1 eval=FALSE
###################################################
## # ex1
## t.sample <- rt(100, df=3)
## # a)
## qqnorm(t.sample)
## qqline(t.sample)
## # b)
## hist(t.sample, freq=FALSE)
## lines(density(t.sample)) # if you like
## # ex2
## norm.sample <- rnorm(100)
## # a)
## qqnorm(norm.sample)
## qqline(norm.sample)
## #
## hist(norm.sample)
## # ex3
## pdf("~/Desktop/comparet_norm.pdf", width=20/2.540, height=20/2.540)
## par(mfrow=c(2,2))
## # first panel
## qqnorm(t.sample)
## qqline(t.sample)
## # second panel
## qqnorm(norm.sample)
## qqline(norm.sample)
## # third panel
## hist(t.sample)
## # fourth panel
## hist(norm.sample)
## dev.off()
## # a)
## # with e.g., ylim=c(-3,3)


###################################################
### chunk number 29: pea.data eval=FALSE
###################################################
## data(pea)
## boxplot(x=split(x=pea$length, f=pea$trt), xlab="levels of the factor \"trt\"", ylab="length of pea sections")
## m0 <- lm(length ~ trt, data=pea)
## coefficients(m0)
## options("contrasts")


###################################################
### chunk number 30: control-sugar eval=FALSE
###################################################
## contr1 <- rbind("control-sugar"=c(1, -1/4, -1/4, -1/4, -1/4))
## m1 <- lm(length ~ trt, data=pea, contrasts=list(trt=mycontr(contr=contr1)))
## summary(m1)


###################################################
### chunk number 31: pure-mixed eval=FALSE
###################################################
## contr2 <- rbind("control-sugar"=c(1, -1/4, -1/4, -1/4, -1/4), "pure-mixed"=c(  0, 1/3, 1/3, -1, 1/3))
## m2 <- lm(length ~ trt, data=pea, contrasts=list(trt=mancontr(contr=contr2)))


###################################################
### chunk number 32: other contrasts eval=FALSE
###################################################
## contr3 <- rbind("control-sugar"=c(1, -1/4, -1/4, -1/4, -1/4), "pure-mixed"=c(  0, 1/3, 1/3, 1, 1/3), "monosaccharides-disaccharides"=c(0,1/2,1/2,0,-1))
## m3 <- lm(length ~ trt, data=pea, contrasts=list(trt=mancontr(contr=contr3)))
## contr4 <- rbind("control-sugar"=c(1, -1/4, -1/4, -1/4, -1/4), "mixed-pure"=c(  0, 1/3, 1/3, 1, 1/3), "monosaccharides-disaccharides"=c(0,1/2,1/2,0,-1), "gluc-fruc"=c(0,1,-1,0,0))
## m4 <- lm(length ~ trt, data=pea, contrasts=list(trt=mancontr(contr=contr4)))


###################################################
### chunk number 33: treatment.contrast eval=FALSE
###################################################
## options(contrasts=c("contr.treatment", "contr.poly"))


###################################################
### chunk number 34: treatment.contrasts.manually eval=FALSE
###################################################
## treatment.contrast <- rbind(c(0,1,0,0,0), c(0,0,1,0,0), c(0,0,0,1,0), c(0,0,0,0,1))
## treatment.contrast.names <- list("control - gluc", "control - fruc", "control - glucfruc", "control - sucr")
## m.treatment <- lm(length ~ trt, data=pea, contrasts=list(trt=mancontr(treatment.contrast, contr.names=treatment.contrast.names)))


###################################################
### chunk number 35:  eval=FALSE
###################################################
## new.trt.cont <- rbind("contr-gluc"=c(1,-1,0,0,0), "contr-fruc"=c(1,0,-1,0,0), "contr-glucfruc"=c(1,0,0,-1,0), "contr-sucr"=c(1,0,0,0,-1))


###################################################
### chunk number 36: sum.contrasts eval=FALSE
###################################################
## options(contrasts=c("contr.sum", "contr.poly"))


###################################################
### chunk number 37:  eval=FALSE
###################################################
## sum.contrast <- list(c(4/5, -1/5, -1/5, -1/5, -1/5), c(-1/5, 4/5, -1/5, -1/5, -1/5), c(-1/5, -1/5, 4/5, -1/5, -1/5), c(-1/5, -1/5, -1/5, 4/5, -1/5))
## sum.contrast.names <- list("control - mean of all", "gluc - mean of all", "fruc - mean of all", "glucfruc - mean of all")
## m.sum <- lm(length ~ trt, data=pea, contrasts=list(trt=mancontr(contr=sum.contrast, contr.names=sum.contrast.names)))


###################################################
### chunk number 38: helmert.contrasts eval=FALSE
###################################################
## options(contrasts=c("contr.helmert", "contr.poly"))


###################################################
### chunk number 39:  eval=FALSE
###################################################
## helmert.contrast <- list(c(-1/2, 1/2, 0, 0, 0), c(-1/6,-1/6,1/3,0,0), c(-1/12, -1/12, -1/12, 1/4, 0), c(-1/20, -1/20, -1/20, -1/20, 1/5))
## helmert.contrast.names <- list("gluc-contr", "fruc-mean(contr,gluc)", "glucfruc-mean(contr,gluc,fruc)", "sucr-mean(contr,gluc,fruc,glucfruc)")
## m.helmert <- lm(length ~ trt, data=pea, contrasts=list(trt=mancontr(contr=helmert.contrast, contr.names=helmert.contrast.names)))


###################################################
### chunk number 40: sdif.contrasts eval=FALSE
###################################################
## options(contrasts=c("contr.sdif", "contr.poly")) # from library MASS


###################################################
### chunk number 41:  eval=FALSE
###################################################
## sdif.contrast <- list(c(-1,1,0,0,0), c(0,-1,1,0,0), c(0,0,-1,1,0), c(0,0,0,-1,1))
## sdif.contrast.names <- list("gluc-control", "fruc-gluc", "glucfruc-fruc", "sucr-glucfruc")
## m.sdif <- lm(length ~ trt, data=pea, contrasts=list(trt=mancontr(contr=sdif.contrast, contr.names=sdif.contrast.names)))


###################################################
### chunk number 42: multiple comparison motivation eval=FALSE
###################################################
## y <- rnorm(1000, sd=1)
## x <- rep(1:100, each=10)
## dat <- data.frame(y=y, x=as.factor(x))
## m <- aov(y ~ x, data=dat)
## summary(m)


###################################################
### chunk number 43: tukey eval=FALSE
###################################################
## m0 <- aov(length ~ trt, data=pea)
## t0 <- TukeyHSD(m0)
## plot(t0)


###################################################
### chunk number 44: paradox eval=FALSE
###################################################
## y <- c(rnorm(10, mean=1.9, sd=0.1), rnorm(10, mean=1.95, sd=0.1), rnorm(10, mean=2, sd=0.1))
## x <- factor(rep(c("a","b","c"), each=10))
## dat <- data.frame(y=y, x=x)
## contr1 <- rbind("a-b"=c(1,-1,0), "b-c"=c(0,1,-1))
## contr2 <- rbind("a-c"=c(1,0,-1,))
## m1 <- aov(y~x, data=dat, contrasts=list(x=mancontr(contr1))); summary.lm(m1)
## m2 <- aov(y~x, data=dat, contrasts=list(x=mancontr(contr2))); summary.lm(m2)
## 
## tapply(dat$y, dat$x, mean)
## t <- TukeyHSD(m2);t


###################################################
### chunk number 45: pr5_ex1
###################################################
library(MASS); library(asuR)
data(immer)


###################################################
### chunk number 46: pr5_ex1 eval=FALSE
###################################################
## data(immer)
## m <- aov((Y1+Y2)/2 ~ Loc + Var, data=immer)
## summary(m)
## co <- rbind("C-D"=c(1,-1,0,0,0,0))
## m1 <- aov((Y1+Y2)/2 ~ Loc + Var, contrasts=list(Loc=mancontr(co)),data=immer)
## tk <- TukeyHSD(m, which="Var")
## plot(tk)
##  densityplot(~(Y1+Y2)/2|Var, data=immer)
##  tapply((immer$Y1+immer$Y2)/2, immer$Var, mean)


###################################################
### chunk number 47: 
###################################################
m.lm <- lm(Fertility ~ Education, data=swiss)
m.glm <- glm(Fertility ~ Education, data=swiss, family=gaussian(link=identity))


###################################################
### chunk number 48: 
###################################################
m.glm.gl <- glm(Fertility ~ Education, data=swiss, family=gaussian(link=log))
#model <- glm(Fertility ~ Education, data=swiss, family=quasi(link=log, variance=constant))


###################################################
### chunk number 49:  eval=FALSE
###################################################
## #model <- glm(Fertility ~ Education, data=swiss, family=quasi(link=log, variance=mu^2))   # about the same
## m.glm.Gl <- glm(Fertility ~ Education, data=swiss, family=Gamma(link=log))


###################################################
### chunk number 50:  eval=FALSE
###################################################
## dep(your.model)


###################################################
### chunk number 51:  eval=FALSE
###################################################
## rpp(your.model)


###################################################
### chunk number 52:  eval=FALSE
###################################################
## lep(your.model)


###################################################
### chunk number 53:  eval=FALSE
###################################################
## hnp(your.model)


###################################################
### chunk number 54:  eval=FALSE
###################################################
## model.glm <- glm(fail ~ temperature, data=oring, family=binomial)
## summary(model.glm)
## ## Coefficients:
## ##             Estimate Std. Error z value Pr(>|z|)  
## ## (Intercept)  15.0429     7.3786   2.039   0.0415 *
## ## temperature  -0.2322     0.1082  -2.145   0.0320 *
## ## trellis.device(device="pdf", file="~/temp/oring.pdf", color = TRUE, width=13/2.54, height=9/2.54)
## ## grid.newpage()
## ## pushViewport(plotViewport(c(5,4,2,2)))
## ## grid.rect()
## ## vp.data <- dataViewport(xscale=c(50,95), yscale=c(0,1))
## ## pushViewport(vp.data)
## ## grid.xaxis()
## ## grid.yaxis()
## ## grid.text("temperature", y=unit(-3, "lines"))
## ## grid.text("probability of failure", x=unit(-3, "lines"), rot=90)
## ## grid.points(x=oring$temperature, y=as.numeric(oring$fail)-1, gp=gpar(col="blue"))
## ## x.i <- seq(from=50, to=95, length=100)
## ## grid.lines(x=unit(x.i, "native"), y=unit(exp(15+x.i*-0.23)/(1+exp(15+x.i*-0.23)), "native"))
## ## grid.rect()
## ## dev.off()


###################################################
### chunk number 55:  eval=FALSE
###################################################
## data(unemployment, package="asuR")
## #
## my.contrast.matrix <- rbind("male-female"=c(1,-1))
## my.model.object <- glm(success~gender, data=unemployment, family=binomial, contrasts=list(gender=mancontr(my.contrast.matrix)))
## summary(my.model.object)
## 
## exp(0.5735)
## #
## 
## p <- c(female=175/(238+175), male=167/(403+167))
## odds <- p/(1-p)
## odds["female"]/odds["male"]


###################################################
### chunk number 56: examples eval=FALSE
###################################################
## data(flowers)
## plantmass <- flowers[flowers$alt=="high","total"]
## ### the mean pant mass for alpine species
## #################################
## # non-parametric bootstrap
## #################################
## flowers.fun <- function(data,i){
##   mean(data[i])
## }
## 
## b0.n <- boot(data=flowers[flowers$alt=="high","total"], statistic=flowers.fun, R=99)
## 
## plot(b0.n)
## print(b0.n)
## # expected sd of the mean
## mean(plantmass)-qt(0.975, length(plantmass)-1)*sqrt(var(plantmass))/sqrt(length(plantmass))
## mean(plantmass)+qt(0.975, length(plantmass)-1)*sqrt(var(plantmass))/sqrt(length(plantmass))
## sqrt(var(plantmass))/sqrt(length(plantmass))
## # ci
## boot.ci(b0.n, type=c("perc"), conf=0.9)
## sort(b0.n$t)
## #
## boot.ci(b0.n, type=c("basic"), conf=0.9)
## boot.ci(b0.n, type=c("norm"), conf=0.9)


###################################################
### chunk number 57: parametric eval=FALSE
###################################################
## #################################
## ### parametric bootstrap
## #################################
## flowers.fun <- function(data){
##   mean(data)
## }
## 
## flowers.sim <- function(data, mle){
##   rnorm(length(data), mean=mle[1], sd=mle[2])
## }
## 
## flowers.mle <- c(mean(plantmass), sqrt(var(plantmass)))
## 
## b0.p <- boot(data=plantmass, statistic=flowers.fun,  R=99, sim="parametric", ran.gen=flowers.sim, mle=flowers.mle)
## 
## plot(b0.p)
## print(b0.p)
## # ci
## boot.ci(b0.p, type=c("perc", "basic", "norm"), conf=0.9)


###################################################
### chunk number 58: parametric eval=FALSE
###################################################
## #################################
## ### bootstrapping a REGRESSION
## #################################
## 
## fit.model <- function(data,i){
##   l1 <- lm(log(flower) ~ log(total) + alt, data=data[i,])
##   coef(l1)["altlow"]
## }
## 
## b0 <- boot(data=flowers, statistic=fit.model, R=99)
## #ci
## boot.ci(b0, type=c("norm", "perc", "basic"))
## 


###################################################
### chunk number 59: introduction::ex2 eval=FALSE
###################################################
## rep(1:3, each=2)
##     rep(1:2, times=3)
##     rep(1:3, each=2, times=3)


###################################################
### chunk number 60: introduction::ex3 eval=FALSE
###################################################
##     paste("trt:",rep(1:3, each=2), sep="")
##     paste("ind:", rep(c(1,2), times=3), sep="")


###################################################
### chunk number 61: introduction::ex4 eval=FALSE
###################################################
## experiment <- data.frame(treatment=paste("trt:",rep(1:3, each=2), sep=""), individual= paste("ind:", rep(c(1,2), times=3), sep=""))
## # dimension
## dim(experiment)
## # class
## str(experiment)
## # add column
## experiment <- cbind(experiment, 2:7)
## # save .Rdata
## save(experiment, file="~/Desktop/experiment.Rdata")
## rm(experiment)
## load(file="~/Desktop/experiment.Rdata")
## # write read .txt
## write.table(experiment, file="~/Desktop/experiment.txt")
## rm(experiment)
## experiment <- read.table(file="~/Desktop/experiment.txt", header=TRUE)


###################################################
### chunk number 62: indexing::ex1 eval=FALSE
###################################################
## mat <- matrix(1:16, nrow=4)
## #third column
## mat[,3]
## # diagonal elemets
## diagonal <- diag(mat)
## # or by hand
## dia <- cbind(c(1:4),c(1:4))
## diagonal <- mat[dia]
## # antidiagonal elements
## antidia <- cbind(c(1:4), c(4:1))
## antidiagonal <- mat[antidia]


###################################################
### chunk number 63: indexing::ex2 eval=FALSE
###################################################
## vec <- as.integer(1:1000)
## even.numbers <- seq(from=2, to=1000, by=2)
## even.numbers <- vec[vec%%2==0] # mutch more elegant by taking the modulo function
## vec[even.numbers] <- 1/vec[even.numbers]
## 
## vec[seq(from=2, to=1000, by=2)] <- 1/(vec[seq(from=2, to=1000, by=2)]) # very compact


###################################################
### chunk number 64: indexing::ex 3 eval=FALSE
###################################################
## # read doc
## help(swiss)
## # sort agriculture
## swiss[order(swiss$Agriculture),]
## # add religion
## swiss <- cbind(swiss, religion=factor(NA, levels=c("catholic", "protestant")))
## swiss$religion[swiss$Catholic>=50] <- "catholic"
## swiss$religion[swiss$Catholic<50] <- "protestant"
## # sort religion and agriculture
## swiss[order(swiss$religion, swiss$Agriculture),]
## # sort provinces
## swiss[order(row.names(swiss)),]
## order(row.names(swiss))[dim(swiss)[1]:1] # for decreasing ordering
## order(row.names(swiss), decreasing=TRUE) # for decreasing ordering made simple
## # random order
## swiss[sample(row.names(swiss)),]
## # remove education
## swiss$Education <- NULL


###################################################
### chunk number 65: graphics::ex1 eval=FALSE
###################################################
## data(trees)
## # a)
## pairs(trees)
## xxp(trees)
## # b)
## pdf(file="~/Desktop/trees_example.pdf", width=13/2.540, height=9/2.540)
## plot(trees$Volume ~ trees$Girth)
## plot(Volume ~ Girth, data=trees)
## plot(trees$Girth, trees$Volume) # in dieser form funktioniert data= nicht!
## dev.off()
## # c)


###################################################
### chunk number 66: graphics::ex2 eval=FALSE
###################################################
## hist(swiss$Fertility)
## plot(swiss$religion, swiss$Fertility)


###################################################
### chunk number 67: graphics::ex3 eval=FALSE
###################################################
## pdf("~/Desktop/swissdata.pdf", width=13/2.540, height=9/2.540)
## par(mar=c(4,4,4,4))
## plot(Agriculture~Fertility, data=swiss, main="swiss data (1888)", xlab="fertility", xlim=c(1,100), ylim=c(1,100), axes=FALSE, ylab="", col="red")
## points(Examination~Fertility, data=swiss, pch=3, xlim=c(1,100), col="blue")
## axis(side=1)
## axis(side=2, col.axis="red", col="red")
## mtext(text="agriculture", side=2, line=3,col="red")
## axis(side=4, col.axis="blue", col="blue")
## mtext(text="examination", side=4, line=3,col="blue")
## legend(x=10,y=90,legend=c("agriculture","examination"),col=c("red","blue"), text.col=c("red","blue"), pch=c(1,3))
## dev.off()


###################################################
### chunk number 68: ex1 eval=FALSE
###################################################
## # ex1
## t.sample <- rt(100, df=3)
## # a)
## qqnorm(t.sample)
## qqline(t.sample)
## # b)
## hist(t.sample, freq=FALSE)
## lines(density(t.sample)) # if you like


###################################################
### chunk number 69: ex2 eval=FALSE
###################################################
## # ex2
## norm.sample <- rnorm(100)
## # a)
## qqnorm(norm.sample)
## qqline(norm.sample)
## #
## hist(norm.sample)


###################################################
### chunk number 70: ex3 eval=FALSE
###################################################
## pdf("~/Desktop/comparet_norm.pdf", width=20/2.540, height=20/2.540)
## par(mfrow=c(2,2))
## # first panel
## qqnorm(t.sample)
## qqline(t.sample)
## # second panel
## qqnorm(norm.sample)
## qqline(norm.sample)
## # third panel
## hist(t.sample)
## # fourth panel
## hist(norm.sample)
## dev.off()
## ## # ex3
## ## pdf("~/Desktop/comparet_norm.pdf", width=20/2.540, height=20/2.540)
## ## par(mfrow=c(2,2))
## ## sample.lim <- range(c(t.sample, norm.sample))
## ## density.lim <- range(c(hist(t.sample, plot=FALSE)$density, hist(norm.sample, plot=FALSE)$density))
## ## quantile.lim <- range(c(qqnorm(t.sample, plot.it=FALSE)$x, qqnorm(norm.sample, plot.it=FALSE)$x))
## ## # first panel
## ## plot(qqnorm(t.sample, plot.it =FALSE)$y ~ qqnorm(t.sample, plot.it =FALSE)$x, xlim=sample.lim, ylim=quantile.lim)
## ## qqline(t.sample)
## ## # second panel
## ## plot(qqnorm(norm.sample, plot.it=FALSE), ylim=sample.lim, xlim=quantile.lim)
## ## qqline(norm.sample)
## ## # third panel
## ## hist(t.sample, freq=FALSE,  xlim=sample.lim, ylim=density.lim)
## ## # fourth panel
## ## hist(norm.sample, freq=FALSE, xlim=sample.lim, ylim=density.lim)
## ## dev.off()
## # a)
## 
## # with e.g., ylim=c(-3,3)


###################################################
### chunk number 71:  eval=FALSE
###################################################
##   m <- aov((Y1+Y2)/2 ~ Loc + Var, data=immer)
##   summary(m)
##   co <- rbind("C-D"=c(1,-1,0,0,0,0))
##   m1 <- aov((Y1+Y2)/2 ~ Loc + Var, contrasts=list(Loc=mancontr(co)),data=immer)
##   tk <- TukeyHSD(m, which="Var")
##   plot(tk)
##   densityplot(~(Y1+Y2)/2|Var, data=immer)
##   tapply((immer$Y1+immer$Y2)/2, immer$Var, mean)


###################################################
### chunk number 72:  eval=FALSE
###################################################
## ### a)
## ## time (hours) = (1/300)*climb(m)  +  (1/4)*distance(km)
## ## time (hours) = 0.00333*climb(m)  +  0.25*distance(km)
## ### b)
## data(hills)
## hills.si <- hills
## hills.si$dist <- hills.si$dist*1.609
## hills.si$time <- hills.si$time/60
## ## why did you know that distance? see the help!!
## hills.si$climb <- hills.si$climb*0.3048
## ### c)
## n0 <- lm(time ~ dist + climb, data=hills.si)
## # NO!
## ### d)
## plot(n0)
## inspect(n0)
## influence.measures(n0)
## summary(n0)
## ### e)
## residuals(n0)["Knock Hill"]
## ## original time
## hills.si[row.names(hills.si)=="Knock Hill","time"]
## 
## n0.s1 <- update(n0, .~., subset=-18)
## 
## 
## n1 <- lm(time ~ dist*climb, data=hills.si, subset=-18)
## 
## inspect(n0)


###################################################
### chunk number 73: ex1 eval=FALSE
###################################################
## data(flowers)
## 
## flowers[order(flowers$alt, flowers$total),]
## 
## subset <- flowers[flowers$flower>20,]
## table(subset$alt)
## 
## flowers[sample(row.names(flowers)),]
## 
## plot(flower ~ total, type="n", data=flowers)
## points(flower ~ total, data=flowers[flowers$alt=="high",], col="red", pch="h")
## points(flower ~ total, data=flowers[flowers$alt=="low",], col="blue", pch="l")
## 
## par(mfrow=c(1,2))
## x <- flowers[flowers$alt=="high","total"]
## hist(x, freq=FALSE, main="untransformed")
## lines(density(x))
## hist(log(x), freq=FALSE, main="log transformed")
## lines(density(log(x)))
## norm(log(x))


###################################################
### chunk number 74: ex2 eval=FALSE
###################################################
## tapply(weight$weightgain, list(weight$source, weight$type), mean)
## tapply(weight$weightgain, list(weight$source, weight$type), var)
## 
## m1 <- lm(weightgain ~ source * type, data=weight)
## 
## levels(weight$source)
## newcontr <- rbind("beef-cereal"=c(1,-1))
## m1 <- lm(weightgain ~ source * type, data=weight, contrasts=list(type=mancontr(newcontr)))


###################################################
### chunk number 75: ex3 eval=FALSE
###################################################
## data(BtheB)
## BtheB$subject <- factor(row.names(BtheB))
## nobs <- nrow(BtheB)
## 
## BtheB.long <- reshape(BtheB, idvar="subject", varying=c("bdi.2m", "bdi.4m", "bdi.6m", "bdi.8m"), direction="long")
## BtheB.long$time <- rep(c(2,4,6,8), rep(nobs,4))
## 
## plot( bdi ~ time, data=BtheB.new[treatment=="TAU", ], xlab="Time (in months)", ylab= "BDI",main="Treated as Usual", ylim=c(0, 55)) 
## plot( bdi ~ time, data=BtheB.new[treatment=="BtheB", ], xlab="Time (in months)", ylab= "BDI",main="Beat the Blues", ylim=c(0, 55)) 
## 
## btb.1 <- lmer(bdi ~bdi.pre + time + treatment + drug + length + (1|subject), data=BthtB_long, na.action=na.omit)
## btb.2 <- lmer(bdi ~bdi.pre + time + treatment + drug + length + (time|subject), data=BthtB_long, na.action=na.omit)
## anova(btb1, btb.2)
## # NOTE:
## # compare only models with the same structure of fixed effects; otherwise use method="ML"


